About
=====

A Moblin assistant in the terminal.

Installation
============

.. code-block:: python

    pip install moblin_assistant

Example usage
=============

Terminal 1.

.. code-block:: text

   $ moblin_assistant run

Terminal 2.

.. code-block:: text

   $ moblin_assistant set_scene Back
